#
# spec file for package docker-compose
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           docker-compose
Version:        2.14.2
Release:        bp155.1.6
Summary:        Define and run multi-container applications with Docker
License:        Apache-2.0
URL:            https://github.com/docker/compose
Source:         compose-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) = 1.19
Requires:       docker
Requires:       docker-compose-switch

%description
Docker Compose is a tool for running multi-container applications on Docker defined using the Compose file format. A Compose file is used to define how the one or more containers that make up your application are configured. Once you have a Compose file, you can create and start your application with a single command: docker compose up.
About update and backward compatibility

Docker Compose V2 is a major version bump release of Docker Compose. It has been completely rewritten from scratch in Golang (V1 was in Python). The installation instructions for Compose V2 differ from V1. V2 is not a standalone binary anymore, and installation scripts will have to be adjusted. Some commands are different.

For a smooth transition from legacy docker-compose 1.xx, please consider installing compose-switch to translate docker-compose ... commands into Compose V2's docker compose .... . Also check V2's --compatibility flag.

%prep
%setup -q -a 1 -n compose-%{version}

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags="-s -w -X github.com/docker/compose/v2/internal.Version=%{version}" \
   -o bin/docker-compose ./cmd/

%install
install -d -m 0755 "%{buildroot}/usr/lib/docker/cli-plugins/"
install -D -m 0755 bin/%{name} "%{buildroot}/usr/lib/docker/cli-plugins/%{name}"

%files
%doc README.md
%license LICENSE
%dir /usr/lib/docker/
%dir /usr/lib/docker/cli-plugins/
/usr/lib/docker/cli-plugins/%{name}

%changelog
* Tue Dec 20 2022 kastl@b1-systems.de
- Update to version 2.14.2:
  * build(deps): bump github.com/containerd/containerd from 1.6.12 to 1.6.14
  * fix race condition on compose logs
  * update projectOptions to be public by renaming it to ProjectOptions
  * detect dependency failed to start
  * set CPU quota
  * Use `DOCKER_DEFAULT_PLATFORM` to determine platform when creating container
  * fix regression running pull --ignore-pull-failures
  * only list running containers when --all=false
  * volume: fix WCOW volume mounts
* Fri Dec 16 2022 kastl@b1-systems.de
- Update to version 2.14.1:
  * apply uid/gid when creating secret from environment
  * load project from explicit --files when set
  * use recently introduced `withSelectedServicesOnly` to reduce code duplication
  * introduce --timestamp option on compose up
  * Address review comments
  * Add --include-deps to push command
  * align `--format` flag and UX with docker cli
  * align `compose ps` output with `docker ps`
  * use StatusError from docker/cli, not "dockerd"
  * resolve --env-file as absolute path
  * fix parsing of repository:tag
  * distinguish stdout and stderr in `up` logs
  * ContainerStart must run sequentially for engine to assing distinct ports within configured range
  * Fix corner case when there's no container to attach to
  * Don't stop pull for images that can be built
  * Squashed commit of the following:
  * build(deps): bump github.com/containerd/containerd from 1.6.10 to 1.6.12
  * remove go.* from e2e tests directory
  * added table of contents inside readme
  * fix race condition collecting pulled images IDs
  * detect required service are gone to stop watching explicit API to stop the log printer
  * update to go1.19.4
  * Cleanup tips from output
  * check only running containers in after down tests of profiles e2e tests
  * Update `e2e` mod deps
  * build(deps): bump go.opentelemetry.io/otel from 1.11.1 to 1.11.2
  * introduce --parallel to limit concurrent engine calls
  * port: improve error-handling if port not found (#10039)
* Mon Dec  5 2022 kastl@b1-systems.de
- BuildRequires go1.19
- Update to version 2.14.0:
  * ci: upgrade to Go 1.19.3 & bump deps
  * schema: add support for tmpfs.mode in mount definition (#10031)
  * test: speed up Cucumber stop test (#10032)
  * Make use of Containers.filter() and isService()
  * Fix replacing "service:x" with "container:y"
  * use StringToBool to detect COMPOSE_IGNORE_ORPHANS
  * use api.Separator to print right image names
  * use DistributionInspect to resolve image digest
  * move image digests resolution to backend
  * Broken Link fixed in compose docs
  * add file header and cleanup profiles e2e tests
  * add e2e tests to check profile activation via targeted service
  * add e2e tests to check no profile usages
  * add e2e tests using explicitly profiles
  * pass services list to projectOrName function to add profiles for targeted services
  * only stop services started by `up` on interruption
  * docs: fix grammatical issues (#9997)
  * implement support for oom_score_adj
  * useDockerDefaultOrServicePlatform fct should return service.platform if defined and present in the build.platforms list (or if the list is empty)
  * configure buildx for plain output if --ansi=never has been set
  * change the default branch of the doc repository
* Thu Nov 24 2022 kastl@b1-systems.de
- Update to version 2.13.0:
  * Update `e2e` module deps
  * ignore error parsing container number label, just warn
  * Update docs
  * Add `--build` option to `compose run`
  * use platform defined by DOCKER_DEFAULT_PLATFORM when pulling and no service platform defined
  * display creation warnings from the engine
  * add e2e tests to check build dependency between services
  * check if a missing image won't be build via a service declared in depends_on section
  * add --no-consistency flag to convert command
  * use COMPOSE_PROFILES value only if no command line arg profiles used
  * build(deps): bump github.com/containerd/containerd from 1.6.9 to 1.6.10
  * exclude issues with the kind/feature label from stale bot process
  * ci: upgrade to compose-go v1.7.0
  * ci: update dependencies to latest
  * ci: remove uses of deprecated gotest.tools v2 (#9935)
  * Update `e2e` module dependencies
  * build(deps): bump github.com/containerd/containerd from 1.6.8 to 1.6.9
  * add support of deploy.reservation.memory
  * Update deps for `e2e` module
  * map deploy.restart_policy.condition to engine values
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1
  * go.mod: update docker-credential-helpers v0.7.0
  * go.mod: remove replace for runc
  * go mod: tidy and group "require" blocks, update comments
* Sat Oct 22 2022 kastl@b1-systems.de
- Update to version 2.12.2:
  * go.mod: docker 5aac513617f072b15322b147052cbda0d451d389 / v22.06-dev
* Sat Oct 22 2022 kastl@b1-systems.de
- Update to version 2.12.1:
  * update docker engine API to apply fix of CVE-2022-39253
  * Update `e2e` module deps
  * build(deps): bump go.opentelemetry.io/otel from 1.11.0 to 1.11.1
  * Skip flaky test in CI
* Tue Oct 18 2022 kastl@b1-systems.de
- Update to version 2.12.0:
  * log the error object instead of the string message only
  * replace deprecated functions
  * bump docker dependencies version
  * Fix Makefile target `validate-go-mod` to only run correct bakefile target
  * Update `e2e` module deps
  * Add Codecov
  * port: fix container name in error message (#9909)
  * github: add feature request template
  * github: switch to issue template form
  * build(deps): bump go.opentelemetry.io/otel from 1.10.0 to 1.11.0
  * Update e2e mod dependencies
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0
  * docs: update with result of `make docs`
  * Add support to push images quietly via compose cli
  * Bump e2e module deps
  * build(deps): bump gotest.tools/v3 from 3.3.0 to 3.4.0
  * don't fail when trying to remove an orphan container during down command
  * Update to go 1.19.2 to address CVE-2022-2879, CVE-2022-2880, CVE-2022-41715
  * ci: update docs repo path
  * Adjust modules sync validating script
  * Add `validate-modules` target to CI matrix
  * Add Makefile, buildx target to ensure root and e2e go.mod are kept in sync
  * Create new `e2e` module to separate out test dependencies, move cucumber tests
  * Removed tests that were replaced by Cucumber features
  * Update go.mod replace
  * Rename start cucumber feature
  * Convert `cascade_stop_test.go` into a cucumber feature `stop.feature`
  * Cucumber test setup/fixtures
* Wed Sep 28 2022 kastl@b1-systems.de
- Update to version 2.11.2:
  * deps: fix race condition during graph traversal (#9878)
  * ci: limit job permissions from default (#9874)
  * remove unnecessary code
  * add more information when service.platform isn't part of  service.build.platforms
  * ci: upgrade to compose-go v1.6.0
  * cli: add shell completion function (#9269)
  * run: clean service command if entrypoint is overridden (#9836)
  * Remove support for `DOCKER_HOST` in `.env` files (#9871)
  * keep the platform defined, in priority, via DOCKER_DEFAULT_PLATFORM or the service.plaform one if no build platforms provided
  * Restore `-s` in `uname` OS detection logic in `Makefile`
  * Streamline GHA workflow
  * Upgrade `actions/setup-go` to v3
  * Skip some tests in CI due to flakiness
  * Increase E2E test timeouts to reduce flakiness
  * Temporarily disable broken E2E tests on Windows
  * Rework Makefile for better Windows support
  * Add GitHub Action workflow to run tests on Mac/Windows runners
  * configure default builder export when no build.platforms defined
  * Remove `/rebase` GitHub Action since it's no longer necessary
* Wed Sep 21 2022 kastl@b1-systems.de
- Update to version 2.11.1:
  * keep the platform defined via DOCKER_DEFAULT_PLATFORM during build if no build platforms provided
  * Fix linting issues
  * Don't overwrite existing dependency condition
  * Add unit tests for `PrepareVolumes`
  * keep the platform defined at service level during build if no build platforms provided
* Thu Sep 15 2022 kastl@b1-systems.de
- Update to version 2.11.0:
  * update compose-go version to v1.5.1
  * add license to file
  * small cleanup + godoc
  * down: refactor image pruning
  * pull: improve output for services with both image+build (#9829)
  * build(deps): bump go.opentelemetry.io/otel from 1.9.0 to 1.10.0
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.5 to 2.3.6 (#9830)
  * Update README.md
  * logs: filter to services from current Compose file (#9811)
  * convert: do not escape $ into $$ when using the --no-interpolate option (#9703)
  * Cleanup E2E tests
  * Add unit tests to graph building logic in `dependencies.go`
  * Restrict compose project to selected services and dependencies on `compose start`
  * Apply newly loaded envvars to "DockerCli" and "APIClient"
  * build(deps): bump go.opentelemetry.io/otel from 1.4.1 to 1.9.0
  * build: label built images for reliable cleanup on `down`
  * ci: upgrade golangci-lint
  * ci: upgrade to Go 1.19.1
  * Cleanup E2E tests
  * patch: build.go access custom labels directly cause panic
  * build(deps): bump github.com/cnabio/cnab-to-oci from 0.3.6 to 0.3.7
  * always use 'docker' export entry when building with 'up' or 'run' commands
  * don't push images at the end of multi-arch build (and simplify e2e tests) support DOCKER_DEFAULT_PLATFORM when 'compose up --build' add tests to check behaviour when DOCKER_DEFAULT_PLATFORM is defined
  * add a test with multiple service builds using platforms in the same compose file
  * fix panic when using 'compose up --build'
  * add support of platforms in build section
  * build(deps): bump github.com/docker/go-units from 0.4.0 to 0.5.0
  * api: fix typo on Push godoc (#9798)
  * ci: reduce noise from dependabot on Docker deps (#9770)
  * Add E2E tests for starting/stopping single services
  * Fix `down` with `--rmi`
  * Only capture exit codes from `exit` events
  * Add E2E tests for `up --exit-code-from`
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 2.10.2:
  * Makefile: mutualize local and Dockerfile build opts (#9776)
  * Revert "Apply newly loaded envvars to `DockerCli` and `APIClient`" (#9792)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 2.10.1:
  * ci: bring back individual checksum files
  * build(deps): bump github.com/moby/buildkit from 0.10.3 to 0.10.4 (#9780)
  * ci: fix checksums checking
  * Pull image regardless of whether it exists locally if `tag=latest`
  * Remove error message showing exit code when using --exit-code-from
  * pull: only skip pull when policy is `missing`/`if_not_present`
  * Wake up!
* Fri Aug 19 2022 dmueller@suse.com
- Update to version 2.10.0:
  * Fix breaking test
  * Update docs for new `compose kill` `--remove-orphans` option
  * Apply compose model on `compose kill`, add `--remove-orphans`
  * Code formatting
  * Give environment variables precedence back to OS over .env
  * Reset the DockerCli and APIClient after loading the environment file
  * up/start/run: don't wait for disabled service
  * create: pull all services logic out of loop; add DependsOn deps
  * build(deps): bump github.com/mattn/go-isatty from 0.0.14 to 0.0.16 (#9754)
  * build windows/arm64 and linux/riscv64 binaries
  * ci: fix checksums file
  * Use compose to pull image twice
  * root: filter out commandConn.Close* warning message
  * Use alpine:3.13.12 to be unique across the test cases
  * readme: fix badges
  * Fix package name
  * Try changing package used to avoid any race condition in tests
  * Better sandboxed workflow and enhanced cross compilation
  * build(deps): bump github.com/containerd/containerd from 1.6.7 to 1.6.8
  * make compose pull tests more expressive
  * lint: add `nolintlint` and clean up `nolint` directives (#9738)
  * lint: run gofmt from Go 1.19 (#9728)
  * don't apply default pull policy from command line if one is define in service configuration
  * build(deps): bump github.com/containerd/containerd from 1.6.6 to 1.6.7
  * update Docker CLI version use in CI to v20.10.17
  * fix version of golangci-lint to v1.47.3, issue with v1.48.0 for now
  * build(deps): bump github.com/cnabio/cnab-to-oci from 0.3.5 to 0.3.6
  * config: use correct YAML marshal func (#9712)
  * docs: remove extra whitespaces in help text (#9710)
  * ci: use latest stable dockerfile syntax & rename docs Dockerfile (#9711)
  * Change `projectOrName()` to check COMPOSE_PROJECT_NAME env var
  * Filter `compose ps` output by provided compose model
  * Add E2E tests for `compose stop` with compose file
  * if command is ran with a compose file, apply the compose model, not just project name
  * up: do not stop dependency containers (#9701)
  * config: case-insensitive env vars on Windows (#9438)
  * build: upgrade BuildKit & docker/distribution
  * build: bump to Go 1.18.5
  * update usage strings for consistency
  * remove unused workflows, especially the pr-closed which always failed
  * Fix breaking TestComposePull test case
  * Avoid pulling same images multiple times ⚡️
* Mon Aug  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Require docker-compose-switch to not break user expectations,
  as otherwise 'zypper in docker-compose' will not provide a docker-compose binary
  (docker-compose only provides a docker plugin, i.e. 'docker compose ...')
* Tue Aug  2 2022 dmueller@suse.com
- Update to version 2.9.0:
  * switch tests back to '_' separator for networks and volumes
  * update to compose-go v1.4.0 as previous version introduced breaking changes
  * Overwrite parent commands PreRun code for `compose version`
  * Improve descriptions about tests in CONTRIBUTING.md
  * Fix LinkLocalIPs in V2
  * Link to BUILDING.md for testing instructions
* Mon Aug  1 2022 kastl@b1-systems.de
- Update to version 2.8.0:
  * Fix go.mod on  replace for compose-go
  * config: ignore image for config hash generation (#9350)
  * Bump compose-go -> 1.3.0
  * use '-' as separator by default for image name
  * as --no-build is set, set service image to default image name
  * cmd: consistent handling no-args commands (#9660)
  * Fixes #9403: Remove Named Pipes from volumeMounts
  * Fix environment variables priority between environment and .env
  * Fix .env and --envfile priorities
  * add pull & build config to project before create add pull flag to create and up documentation
  * introduce --pull
  * use Google addlicense instead of kunalkushwaha/ltag
  * update cli-doc-tool and update the doc with this new version
  * remove usage of GO111MODULE option in gh actions
  * use env variable for golang version and updates gh actions from v2 to v3
  * ci(docs): use push-to-fork when creating pr
  * remove unused sessionConfig param for addSecretsConfig function
* Wed Jul 20 2022 kastl@b1-systems.de
- Update to version 2.7.0:
  * Bump compose-go -> v1.2.9
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0
  * Fix nolint issues
  * Add "style" tag to gocritic
  * Add "opinionated" tag to gocritic
  * Add "diagnostic" tag to gocritic
  * Add gocritic to linters
  * add 2 named networks with close name in the networks test suite to guarantee the good distinction on network names
  * update go to 1.18.4
  * keep the container reference when volumes_from target a container and not a service
  * build.go: Access customLabels directly instead of by reference
  * check the exact network's name before creating or stopping it NetworkList API doesn't return the extact name match, so we can retrieve more than one network with a request
  * build(deps): bump github.com/cnabio/cnab-to-oci from 0.3.4 to 0.3.5
  * Fix typo in docker_compose_pull
  * Fix typo in compose pull documentation
  * add new targets to build Compose binary before running e2e tests
  * Fix golangci syntax error in run configuration
  * add support of environment secret during build step
  * Use switch/case instead of static map for simplicity
  * TC: Add missing tests for argumetns
  * TC: fix naming
  * TC: Use map to simplify flag conversion and avoid multilple if statements
  * e2e: add more start/stop test cases
  * build(deps): bump github.com/stretchr/testify from 1.7.5 to 1.8.0
  * Update logic to keep `compose stop` and `restart` from affecting one-offs
  * e2e: split out `pause` tests and add more cases
  * fix: panic caused by empty string argument
  * build(deps): bump github.com/hashicorp/go-version from 1.5.0 to 1.6.0
  * Blacklist ioutil pkg in golangci-lint
  * Use alpine instead of ubuntu for E2E compose file, no need to include version
  * Replace deprecated ioutil pkg with os & io
  * test: add copyright notice
  * ci: release workflow to open a PR on docs repo with latest changes
  * build(deps): bump github.com/stretchr/testify from 1.7.4 to 1.7.5
  * build(deps): bump github.com/cnabio/cnab-to-oci from 0.3.3 to 0.3.4
  * network: make test mock consistent throughout
  * build: respect dependency order for classic builder
  * networks: prevent issues due to duplicate names
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.4
  * Use appropriate dependency condition for one-shot containers when running `compose up --wait`
* Wed Jun 29 2022 Johannes Kastl <kastl@b1-systems.de>
- first version of package docker-compose (v2)
  - v2 was rewritten in golang, while v1 was in Python
  - as they behaviour changes between v1 (python-docker-compose) and v2,
    this package does not obsolete the v1 package
